use crate::{base::service::BaseService, utils::errors::AppError};
use axum::{http::StatusCode, response::IntoResponse, Json};
use sea_orm::{ActiveModelTrait, DatabaseConnection, EntityTrait, ModelTrait};

pub struct BaseController<Entity, Model, ActiveModel>
where
    Entity: EntityTrait,
    Model: ModelTrait + Send + Sync + 'static,
    ActiveModel: ActiveModelTrait + Send + Sync + 'static,
{
    service: BaseService<Entity, Model, ActiveModel>,
}

impl<Entity, Model, ActiveModel> BaseController<Entity, Model, ActiveModel>
where
    Entity: EntityTrait,
    Model: ModelTrait + Send + Sync + 'static,
    ActiveModel: ActiveModelTrait + Send + Sync + 'static,
{
    pub fn new() -> Self {
        Self {
            service: BaseService::new(),
        }
    }

    pub async fn create(
        &self,
        state: State<DatabaseConnection>,
        Json(data): Json<ActiveModel>,
    ) -> Result<IntoResponse, AppError> {
        let model = self.service.create(&state, data).await?;
        Ok((StatusCode::CREATED, Json(model)))
    }
}
