use crate::utils::errors::AppError;
use async_trait::async_trait;
use sea_orm::{ActiveModelTrait, DatabaseConnection, EntityTrait, ModelTrait};

#[async_trait]
pub trait IService<Entity, Model, ActiveModel>
where
    Entity: EntityTrait,
    Model: ModelTrait + Send + Sync,
    ActiveModel: ActiveModelTrait + Send + Sync,
{
    async fn create(&self, db: &DatabaseConnection, data: ActiveModel) -> Result<Model, AppError>;
    async fn get_by_id(&self, db: &DatabaseConnection, id: i32) -> Result<Option<Model>, AppError>;
    async fn get_all(&self, db: &DatabaseConnection) -> Result<Vec<Model>, AppError>;
    async fn update(
        &self,
        db: &DatabaseConnection,
        id: i32,
        data: ActiveModel,
    ) -> Result<Model, AppError>;
    async fn delete(&self, db: &DatabaseConnection, id: i32) -> Result<(), AppError>;
}
